==> axiom-1.2.22-src.zip: axiom-1.2.22/systests/osgi-tests/src/test/java/org/apache/axiom/test/SystemDepsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.test;

import static org.junit.Assert.assertEquals;
import static org.ops4j.pax.exam.CoreOptions.junitBundles;
import static org.ops4j.pax.exam.CoreOptions.options;
import static org.ops4j.pax.exam.CoreOptions.url;

import java.io.StringReader;

import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMXMLBuilderFactory;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.ops4j.pax.exam.Configuration;
import org.ops4j.pax.exam.Option;
import org.ops4j.pax.exam.junit.PaxExam;
import org.ops4j.pax.exam.spi.reactors.ExamReactorStrategy;
import org.ops4j.pax.exam.spi.reactors.PerClass;

/**
 * Tests that Axiom works properly if the Activation and StAX APIs are resolved from the framework
 * bundle (i.e. from the JRE). This also tests that Axiom works with the StAX implementation from
 * the JRE.
 * <p>
 * Note that this test relies on the fact that the Maven build requires at least Java 1.6.
 */
@RunWith(PaxExam.class)
@ExamReactorStrategy(PerClass.class)
public class SystemDepsTest {
    @Configuration
    public static Option[] configuration() {
        return options(
                url("link:classpath:org.apache.james.apache-mime4j-core.link"),
                url("link:classpath:org.apache.ws.commons.axiom.axiom-api.link"),
                url("link:classpath:org.apache.ws.commons.axiom.axiom-impl.link"),
                junitBundles());
    }
    
    @Test
    public void testCreateOMBuilder() throws Exception {
        OMElement element = OMXMLBuilderFactory.createOMBuilder(new StringReader(
                "<root/>")).getDocumentElement();
        assertEquals("root", element.getLocalName());
    }
}

==> axiom-1.4.0-src.zip: axiom-1.4.0/systests/osgi-tests/src/test/java/org/apache/axiom/test/SystemDepsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.test;

import static org.junit.Assert.assertEquals;
import static org.ops4j.pax.exam.CoreOptions.junitBundles;
import static org.ops4j.pax.exam.CoreOptions.options;
import static org.ops4j.pax.exam.CoreOptions.url;

import java.io.StringReader;

import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMXMLBuilderFactory;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.ops4j.pax.exam.Configuration;
import org.ops4j.pax.exam.Option;
import org.ops4j.pax.exam.junit.PaxExam;
import org.ops4j.pax.exam.spi.reactors.ExamReactorStrategy;
import org.ops4j.pax.exam.spi.reactors.PerClass;

/**
 * Tests that Axiom works properly with the StAX implementation from the JRE.
 */
@RunWith(PaxExam.class)
@ExamReactorStrategy(PerClass.class)
public class SystemDepsTest {
    @Configuration
    public static Option[] configuration() {
        return options(
                url("link:classpath:com.sun.activation.jakarta.activation.link"),
                url("link:classpath:org.apache.james.apache-mime4j-core.link"),
                url("link:classpath:org.apache.ws.commons.axiom.axiom-api.link"),
                url("link:classpath:org.apache.ws.commons.axiom.axiom-impl.link"),
                junitBundles());
    }
    
    @Test
    public void testCreateOMBuilder() throws Exception {
        OMElement element = OMXMLBuilderFactory.createOMBuilder(new StringReader(
                "<root/>")).getDocumentElement();
        assertEquals("root", element.getLocalName());
    }
}
